# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/dataset_validation_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/dataset_validation_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$gateway/dataset_validation_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xba\x05\n\x14\x44\x61tasetValidationJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\x0c\x64\x61taset_name\x18\x07 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x37\n\x06\x66ormat\x18\x08 \x01(\x0e\x32 .gateway.DatasetValidationFormatB\x05\xe2\x41\x02\x02\x05\x12:\n\x06result\x18\t \x01(\x0e\x32#.gateway.DatasetValidationJobResultB\x05\xe2\x41\x02\x03\x05\x12\x1f\n\x10validation_error\x18\n \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1c\n\rdataset_names\x18\x0b \x03(\tB\x05\xe2\x41\x02\x01\x05\x12\x35\n\x0bupdate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x16\n\x07rewards\x18\x18 \x03(\tB\x05\xe2\x41\x02\x01\x05:\xac\x01\xea\x41\x99\x01\n%api.fireworks.ai/DatasetValidationJob\x12\x43\x61\x63\x63ounts/{AccountId}/DatasetValidationJobs/{DatasetValidationJobId}*\x15\x44\x61tasetValidationJobs2\x14\x44\x61tasetValidationJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"4\n\x1eGetDatasetValidationJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xa7\x01\n!CreateDatasetValidationJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x43\n\x16\x64\x61taset_validation_job\x18\x02 \x01(\x0b\x32\x1d.gateway.DatasetValidationJobB\x04\xe2\x41\x01\x02\x12\'\n\x19\x64\x61taset_validation_job_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\x99\x01\n ListDatasetValidationJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x90\x01\n!ListDatasetValidationJobsResponse\x12>\n\x17\x64\x61taset_validation_jobs\x18\x01 \x03(\x0b\x32\x1d.gateway.DatasetValidationJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"7\n!DeleteDatasetValidationJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02*\xb6\x02\n\x17\x44\x61tasetValidationFormat\x12)\n%DATASET_VALIDATION_FORMAT_UNSPECIFIED\x10\x00\x12\"\n\x1e\x44\x41TASET_VALIDATION_FORMAT_CHAT\x10\x01\x12*\n&DATASET_VALIDATION_FORMAT_CHAT_RELAXED\x10\x02\x12\"\n\x1e\x44\x41TASET_VALIDATION_FORMAT_RLOR\x10\x03\x12\x34\n0DATASET_VALIDATION_FORMAT_BATCH_INFERENCE_STRICT\x10\x04\x12\x46\nBDATASET_VALIDATION_FORMAT_BATCH_INFERENCE_ALLOW_TRAILING_ASSISTANT\x10\x05*\xa1\x01\n\x1a\x44\x61tasetValidationJobResult\x12-\n)DATASET_VALIDATION_JOB_RESULT_UNSPECIFIED\x10\x00\x12)\n%DATASET_VALIDATION_JOB_RESULT_SUCCESS\x10\x01\x12)\n%DATASET_VALIDATION_JOB_RESULT_FAILURE\x10\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.dataset_validation_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['name']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['state']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['status']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_name']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_name']._serialized_options = b'\342A\002\002\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['format']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['format']._serialized_options = b'\342A\002\002\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['result']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['result']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['validation_error']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['validation_error']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_names']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_names']._serialized_options = b'\342A\002\001\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['rewards']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['rewards']._serialized_options = b'\342A\002\001\005'
  _globals['_DATASETVALIDATIONJOB']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB']._serialized_options = b'\352A\231\001\n%api.fireworks.ai/DatasetValidationJob\022Caccounts/{AccountId}/DatasetValidationJobs/{DatasetValidationJobId}*\025DatasetValidationJobs2\024DatasetValidationJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job']._loaded_options = None
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job_id']._loaded_options = None
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DATASETVALIDATIONFORMAT']._serialized_start=1473
  _globals['_DATASETVALIDATIONFORMAT']._serialized_end=1783
  _globals['_DATASETVALIDATIONJOBRESULT']._serialized_start=1786
  _globals['_DATASETVALIDATIONJOBRESULT']._serialized_end=1947
  _globals['_DATASETVALIDATIONJOB']._serialized_start=188
  _globals['_DATASETVALIDATIONJOB']._serialized_end=886
  _globals['_GETDATASETVALIDATIONJOBREQUEST']._serialized_start=888
  _globals['_GETDATASETVALIDATIONJOBREQUEST']._serialized_end=940
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST']._serialized_start=943
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST']._serialized_end=1110
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST']._serialized_start=1113
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST']._serialized_end=1266
  _globals['_LISTDATASETVALIDATIONJOBSRESPONSE']._serialized_start=1269
  _globals['_LISTDATASETVALIDATIONJOBSRESPONSE']._serialized_end=1413
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST']._serialized_start=1415
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST']._serialized_end=1470
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/rlor_trainer_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/rlor_trainer_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import job_progress_pb2 as gateway_dot_job__progress__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import training_pb2 as gateway_dot_training__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egateway/rlor_trainer_job.proto\x12\x07gateway\x1a\x1agateway/job_progress.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x16gateway/training.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x06\n\x0eRlorTrainerJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x39\n\x0e\x63ompleted_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x07\x64\x61taset\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\x12 \n\x12\x65valuation_dataset\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12 \n\x12\x65val_auto_carveout\x18\x07 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\'\n\x05state\x18\x08 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\t \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\n \x01(\tB\x05\xe2\x41\x02\x03\x05\x12:\n\x0ftraining_config\x18\x0b \x01(\x0b\x32\x1b.gateway.BaseTrainingConfigB\x04\xe2\x41\x01\x01\x12\x1a\n\x0ereward_weights\x18\x0c \x03(\tB\x02\x18\x01\x12\x30\n\x0cwandb_config\x18\r \x01(\x0b\x32\x14.gateway.WandbConfigB\x04\xe2\x41\x01\x01\x12\x46\n\"reinforcement_fine_tuning_epoch_id\x18\x0e \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12G\n\x0cjob_progress\x18\x0f \x01(\x0b\x32\x14.gateway.JobProgressB\x1b\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY:\x8d\x01\xea\x41{\n\x1f\x61pi.fireworks.ai/RlorTrainerJob\x12\x37\x61\x63\x63ounts/{AccountId}/rlorTrainerJobs/{RlorTrainerJobId}*\x0frlorTrainerJobs2\x0erlorTrainerJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\".\n\x18GetRlorTrainerJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xba\x01\n\x1b\x43reateRlorTrainerJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x37\n\x10rlor_trainer_job\x18\x02 \x01(\x0b\x32\x17.gateway.RlorTrainerJobB\x04\xe2\x41\x01\x02\x12)\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12!\n\x13rlor_trainer_job_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"\x93\x01\n\x1aListRlorTrainerJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"~\n\x1bListRlorTrainerJobsResponse\x12\x32\n\x11rlor_trainer_jobs\x18\x01 \x03(\x0b\x32\x17.gateway.RlorTrainerJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"1\n\x1b\x44\x65leteRlorTrainerJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.rlor_trainer_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_RLORTRAINERJOB'].fields_by_name['name']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['completed_time']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['completed_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['dataset']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_RLORTRAINERJOB'].fields_by_name['evaluation_dataset']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['evaluation_dataset']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['eval_auto_carveout']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['eval_auto_carveout']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['state']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['status']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['training_config']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['training_config']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['reward_weights']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['reward_weights']._serialized_options = b'\030\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_RLORTRAINERJOB'].fields_by_name['job_progress']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['job_progress']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_RLORTRAINERJOB']._loaded_options = None
  _globals['_RLORTRAINERJOB']._serialized_options = b'\352A{\n\037api.fireworks.ai/RlorTrainerJob\0227accounts/{AccountId}/rlorTrainerJobs/{RlorTrainerJobId}*\017rlorTrainerJobs2\016rlorTrainerJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETRLORTRAINERJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETRLORTRAINERJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['debug']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['debug']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job_id']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETERLORTRAINERJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETERLORTRAINERJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_RLORTRAINERJOB']._serialized_start=284
  _globals['_RLORTRAINERJOB']._serialized_end=1090
  _globals['_GETRLORTRAINERJOBREQUEST']._serialized_start=1092
  _globals['_GETRLORTRAINERJOBREQUEST']._serialized_end=1138
  _globals['_CREATERLORTRAINERJOBREQUEST']._serialized_start=1141
  _globals['_CREATERLORTRAINERJOBREQUEST']._serialized_end=1327
  _globals['_LISTRLORTRAINERJOBSREQUEST']._serialized_start=1330
  _globals['_LISTRLORTRAINERJOBSREQUEST']._serialized_end=1477
  _globals['_LISTRLORTRAINERJOBSRESPONSE']._serialized_start=1479
  _globals['_LISTRLORTRAINERJOBSRESPONSE']._serialized_end=1605
  _globals['_DELETERLORTRAINERJOBREQUEST']._serialized_start=1607
  _globals['_DELETERLORTRAINERJOBREQUEST']._serialized_end=1656
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InferenceLog(_message.Message):
    __slots__ = ("name", "create_time", "model", "request_type", "input_content", "output_content", "duration_ms", "status_code", "metadata", "update_time")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    REQUEST_TYPE_FIELD_NUMBER: _ClassVar[int]
    INPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
    DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    create_time: _timestamp_pb2.Timestamp
    model: str
    request_type: str
    input_content: str
    output_content: str
    duration_ms: int
    status_code: int
    metadata: _containers.ScalarMap[str, str]
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., model: _Optional[str] = ..., request_type: _Optional[str] = ..., input_content: _Optional[str] = ..., output_content: _Optional[str] = ..., duration_ms: _Optional[int] = ..., status_code: _Optional[int] = ..., metadata: _Optional[_Mapping[str, str]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetInferenceLogRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteInferenceLogRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListInferenceLogsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListInferenceLogsResponse(_message.Message):
    __slots__ = ("inference_logs", "next_page_token", "total_size")
    INFERENCE_LOGS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    inference_logs: _containers.RepeatedCompositeFieldContainer[InferenceLog]
    next_page_token: str
    total_size: int
    def __init__(self, inference_logs: _Optional[_Iterable[_Union[InferenceLog, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/batch_inference_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/batch_inference_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import job_progress_pb2 as gateway_dot_job__progress__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!gateway/batch_inference_job.proto\x12\x07gateway\x1a\x18gateway/deployment.proto\x1a\x1agateway/job_progress.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\t\n\x11\x42\x61tchInferenceJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0b\x65xpire_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x06 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x13\n\x05model\x18\x08 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1e\n\x10input_dataset_id\x18\t \x01(\tB\x04\xe2\x41\x01\x02\x12\x1f\n\x11output_dataset_id\x18\n \x01(\tB\x04\xe2\x41\x01\x02\x12=\n\x12\x61ppend_to_messages\x18\x0b \x01(\x0b\x32\x19.gateway.AppendToMessagesB\x04\xe2\x41\x01\x01H\x00\x12@\n\x14inference_parameters\x18\x0c \x01(\x0b\x32\x1c.gateway.InferenceParametersB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\'\n\x19\x65nding_assistant_messages\x18\x0e \x01(\tB\x04\xe2\x41\x01\x01\x12%\n\x06region\x18\x0f \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x01\x12$\n\x11max_replica_count\x18\x10 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01\x88\x01\x01\x12\x38\n\x10\x61\x63\x63\x65lerator_type\x18\x11 \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x04\xe2\x41\x01\x01\x12$\n\x11\x61\x63\x63\x65lerator_count\x18\x12 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x02\x88\x01\x01\x12\x36\n\tprecision\x18\x13 \x01(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x04\xe2\x41\x01\x01\x12\x46\n\"reinforcement_fine_tuning_epoch_id\x18\x14 \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12;\n\x17skip_dataset_validation\x18\x15 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12G\n\x0cjob_progress\x18\x16 \x01(\x0b\x32\x14.gateway.JobProgressB\x1b\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY:\x9d\x01\xea\x41\x8a\x01\n\"api.fireworks.ai/BatchInferenceJob\x12=accounts/{AccountId}/batchInferenceJobs/{BatchInferenceJobId}*\x12\x62\x61tchInferenceJobs2\x11\x62\x61tchInferenceJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\x08\n\x06\x66ormatB\x14\n\x12_max_replica_countB\x14\n\x12_accelerator_count\"\x87\x01\n\x13InferenceParameters\x12\x12\n\nmax_tokens\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x02\x12\r\n\x05top_p\x18\x03 \x01(\x02\x12\t\n\x01n\x18\x04 \x01(\x05\x12\x18\n\nextra_body\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x13\n\x05top_k\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01\"5\n\x10\x41ppendToMessages\x12!\n\x19unroll_multiple_responses\x18\x01 \x01(\x08\"1\n\x1bGetBatchInferenceJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x9b\x01\n\x1e\x43reateBatchInferenceJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12=\n\x13\x62\x61tch_inference_job\x18\x02 \x01(\x0b\x32\x1a.gateway.BatchInferenceJobB\x04\xe2\x41\x01\x02\x12$\n\x16\x62\x61tch_inference_job_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\xb3\x01\n\x1dListBatchInferenceJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1b\n\rshow_internal\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01\"\x87\x01\n\x1eListBatchInferenceJobsResponse\x12\x38\n\x14\x62\x61tch_inference_jobs\x18\x01 \x03(\x0b\x32\x1a.gateway.BatchInferenceJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x96\x01\n\x1eUpdateBatchInferenceJobRequest\x12=\n\x13\x62\x61tch_inference_job\x18\x01 \x01(\x0b\x32\x1a.gateway.BatchInferenceJobB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"4\n\x1e\x44\x65leteBatchInferenceJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xe8\x01\n.GetBatchInferenceJobInputUploadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12k\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32K.gateway.GetBatchInferenceJobInputUploadEndpointRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xe3\x01\n/GetBatchInferenceJobInputUploadEndpointResponse\x12s\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32R.gateway.GetBatchInferenceJobInputUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n+ValidateBatchInferenceJobInputUploadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"G\n1GetBatchInferenceJobOutputDownloadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xe9\x01\n2GetBatchInferenceJobOutputDownloadEndpointResponse\x12v\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32U.gateway.GetBatchInferenceJobOutputDownloadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.batch_inference_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['name']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['expire_time']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['expire_time']._serialized_options = b'\342A\001\003'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['state']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['status']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['model']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['model']._serialized_options = b'\342A\001\002'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['input_dataset_id']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['input_dataset_id']._serialized_options = b'\342A\001\002'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['output_dataset_id']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['output_dataset_id']._serialized_options = b'\342A\001\002'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['append_to_messages']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['append_to_messages']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['inference_parameters']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['inference_parameters']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['ending_assistant_messages']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['ending_assistant_messages']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['region']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['region']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['max_replica_count']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['max_replica_count']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['precision']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['precision']._serialized_options = b'\342A\001\001'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['skip_dataset_validation']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['skip_dataset_validation']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_BATCHINFERENCEJOB'].fields_by_name['job_progress']._loaded_options = None
  _globals['_BATCHINFERENCEJOB'].fields_by_name['job_progress']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_BATCHINFERENCEJOB']._loaded_options = None
  _globals['_BATCHINFERENCEJOB']._serialized_options = b'\352A\212\001\n\"api.fireworks.ai/BatchInferenceJob\022=accounts/{AccountId}/batchInferenceJobs/{BatchInferenceJobId}*\022batchInferenceJobs2\021batchInferenceJob\202\361\004\013\n\007Account\030\001'
  _globals['_INFERENCEPARAMETERS'].fields_by_name['extra_body']._loaded_options = None
  _globals['_INFERENCEPARAMETERS'].fields_by_name['extra_body']._serialized_options = b'\342A\001\001'
  _globals['_INFERENCEPARAMETERS'].fields_by_name['top_k']._loaded_options = None
  _globals['_INFERENCEPARAMETERS'].fields_by_name['top_k']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHINFERENCEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEBATCHINFERENCEJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEBATCHINFERENCEJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEBATCHINFERENCEJOBREQUEST'].fields_by_name['batch_inference_job']._loaded_options = None
  _globals['_CREATEBATCHINFERENCEJOBREQUEST'].fields_by_name['batch_inference_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEBATCHINFERENCEJOBREQUEST'].fields_by_name['batch_inference_job_id']._loaded_options = None
  _globals['_CREATEBATCHINFERENCEJOBREQUEST'].fields_by_name['batch_inference_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['show_internal']._loaded_options = None
  _globals['_LISTBATCHINFERENCEJOBSREQUEST'].fields_by_name['show_internal']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEBATCHINFERENCEJOBREQUEST'].fields_by_name['batch_inference_job']._loaded_options = None
  _globals['_UPDATEBATCHINFERENCEJOBREQUEST'].fields_by_name['batch_inference_job']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEBATCHINFERENCEJOBREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEBATCHINFERENCEJOBREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEBATCHINFERENCEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEBATCHINFERENCEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATEBATCHINFERENCEJOBINPUTUPLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_VALIDATEBATCHINFERENCEJOBINPUTUPLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHINFERENCEJOB']._serialized_start=302
  _globals['_BATCHINFERENCEJOB']._serialized_end=1549
  _globals['_INFERENCEPARAMETERS']._serialized_start=1552
  _globals['_INFERENCEPARAMETERS']._serialized_end=1687
  _globals['_APPENDTOMESSAGES']._serialized_start=1689
  _globals['_APPENDTOMESSAGES']._serialized_end=1742
  _globals['_GETBATCHINFERENCEJOBREQUEST']._serialized_start=1744
  _globals['_GETBATCHINFERENCEJOBREQUEST']._serialized_end=1793
  _globals['_CREATEBATCHINFERENCEJOBREQUEST']._serialized_start=1796
  _globals['_CREATEBATCHINFERENCEJOBREQUEST']._serialized_end=1951
  _globals['_LISTBATCHINFERENCEJOBSREQUEST']._serialized_start=1954
  _globals['_LISTBATCHINFERENCEJOBSREQUEST']._serialized_end=2133
  _globals['_LISTBATCHINFERENCEJOBSRESPONSE']._serialized_start=2136
  _globals['_LISTBATCHINFERENCEJOBSRESPONSE']._serialized_end=2271
  _globals['_UPDATEBATCHINFERENCEJOBREQUEST']._serialized_start=2274
  _globals['_UPDATEBATCHINFERENCEJOBREQUEST']._serialized_end=2424
  _globals['_DELETEBATCHINFERENCEJOBREQUEST']._serialized_start=2426
  _globals['_DELETEBATCHINFERENCEJOBREQUEST']._serialized_end=2478
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST']._serialized_start=2481
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST']._serialized_end=2713
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_start=2660
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_end=2713
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTRESPONSE']._serialized_start=2716
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTRESPONSE']._serialized_end=2943
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2884
  _globals['_GETBATCHINFERENCEJOBINPUTUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2943
  _globals['_VALIDATEBATCHINFERENCEJOBINPUTUPLOADREQUEST']._serialized_start=2945
  _globals['_VALIDATEBATCHINFERENCEJOBINPUTUPLOADREQUEST']._serialized_end=3010
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTREQUEST']._serialized_start=3012
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTREQUEST']._serialized_end=3083
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTRESPONSE']._serialized_start=3086
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTRESPONSE']._serialized_end=3319
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2884
  _globals['_GETBATCHINFERENCEJOBOUTPUTDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2943
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/node_pool_binding.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/node_pool_binding.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgateway/node_pool_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\x0fNodePoolBinding\x12\x19\n\naccount_id\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncluster_id\x18\x02 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\x0cnode_pool_id\x18\x03 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x17\n\tprincipal\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\"o\n\x1c\x43reateNodePoolBindingRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x39\n\x11node_pool_binding\x18\x02 \x01(\x0b\x32\x18.gateway.NodePoolBindingB\x04\xe2\x41\x01\x02\"\x94\x01\n\x1bListNodePoolBindingsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x81\x01\n\x1cListNodePoolBindingsResponse\x12\x34\n\x12node_pool_bindings\x18\x01 \x03(\x0b\x32\x18.gateway.NodePoolBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"Y\n\x1c\x44\x65leteNodePoolBindingRequest\x12\x39\n\x11node_pool_binding\x18\x02 \x01(\x0b\x32\x18.gateway.NodePoolBindingB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.node_pool_binding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_NODEPOOLBINDING'].fields_by_name['account_id']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['account_id']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['cluster_id']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['node_pool_id']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['create_time']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['principal']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['principal']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._loaded_options = None
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._loaded_options = None
  _globals['_DELETENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._serialized_options = b'\342A\001\002'
  _globals['_NODEPOOLBINDING']._serialized_start=111
  _globals['_NODEPOOLBINDING']._serialized_end=292
  _globals['_CREATENODEPOOLBINDINGREQUEST']._serialized_start=294
  _globals['_CREATENODEPOOLBINDINGREQUEST']._serialized_end=405
  _globals['_LISTNODEPOOLBINDINGSREQUEST']._serialized_start=408
  _globals['_LISTNODEPOOLBINDINGSREQUEST']._serialized_end=556
  _globals['_LISTNODEPOOLBINDINGSRESPONSE']._serialized_start=559
  _globals['_LISTNODEPOOLBINDINGSRESPONSE']._serialized_end=688
  _globals['_DELETENODEPOOLBINDINGREQUEST']._serialized_start=690
  _globals['_DELETENODEPOOLBINDINGREQUEST']._serialized_end=779
# @@protoc_insertion_point(module_scope)



import asyncio
from datetime import datetime
from typing import Literal, Optional
from fireworks.gateway import Gateway
from fireworks.dataset import Dataset
from fireworks.control_plane.generated.protos.gateway import (
    CreateSupervisedFineTuningJobRequest,
    JobState,
    Region,
    SupervisedFineTuningJob as SupervisedFineTuningJobProto,
    ListSupervisedFineTuningJobsRequest,
    SupervisedFineTuningJobWeightPrecision,
    WandbConfig,
    AcceleratorType as AcceleratorTypeEnum,
)
from google.protobuf.timestamp_pb2 import Timestamp as TimestampProto
from fireworks.control_plane.generated.protos_grpcio.gateway.supervised_fine_tuning_job_pb2 import (
    ListSupervisedFineTuningJobsRequest as SyncListSupervisedFineTuningJobsRequest,
    CreateSupervisedFineTuningJobRequest as SyncCreateSupervisedFineTuningJobRequest,
    SupervisedFineTuningJob as SyncSupervisedFineTuningJob,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.status_pb2 import (
    JobState as SyncJobState,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.wandb_pb2 import (
    WandbConfig as SyncWandbConfig,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.deployment_pb2 import (
    AcceleratorType as SyncAcceleratorType,
    Region as SyncRegion,
)
from fireworks.llm import LLM
from fireworks._literals import RegionLiteral, AcceleratorTypeLiteral


def wandb_config_proto_to_dataclass(wandb_config: SyncWandbConfig) -> WandbConfig:
    return WandbConfig(
        enabled=wandb_config.enabled,
        api_key=wandb_config.api_key,
        project=wandb_config.project,
        entity=wandb_config.entity,
        run_id=wandb_config.run_id,
    )


def timestamp_proto_to_datetime(timestamp: TimestampProto) -> datetime:
    dt = datetime.fromtimestamp(timestamp.seconds + timestamp.nanos / 1e9)
    return dt


def region_proto_to_literal(region: SyncRegion) -> RegionLiteral:
    if region == SyncRegion.REGION_UNSPECIFIED:
        return "REGION_UNSPECIFIED"
    elif region == SyncRegion.US_IOWA_1:
        return "US_IOWA_1"
    elif region == SyncRegion.US_VIRGINIA_1:
        return "US_VIRGINIA_1"
    elif region == SyncRegion.US_VIRGINIA_2:
        return "US_VIRGINIA_2"
    elif region == SyncRegion.US_ILLINOIS_1:
        return "US_ILLINOIS_1"
    elif region == SyncRegion.AP_TOKYO_1:
        return "AP_TOKYO_1"
    elif region == SyncRegion.EU_LONDON_1:
        return "EU_LONDON_1"
    elif region == SyncRegion.US_ARIZONA_1:
        return "US_ARIZONA_1"
    elif region == SyncRegion.US_TEXAS_1:
        return "US_TEXAS_1"
    elif region == SyncRegion.US_ILLINOIS_2:
        return "US_ILLINOIS_2"
    elif region == SyncRegion.EU_FRANKFURT_1:
        return "EU_FRANKFURT_1"
    elif region == SyncRegion.US_TEXAS_2:
        return "US_TEXAS_2"
    elif region == SyncRegion.EU_PARIS_1:
        return "EU_PARIS_1"
    elif region == SyncRegion.EU_HELSINKI_1:
        return "EU_HELSINKI_1"
    elif region == SyncRegion.US_NEVADA_1:
        return "US_NEVADA_1"
    elif region == SyncRegion.EU_ICELAND_1:
        return "EU_ICELAND_1"
    elif region == SyncRegion.EU_ICELAND_2:
        return "EU_ICELAND_2"
    elif region == SyncRegion.US_WASHINGTON_1:
        return "US_WASHINGTON_1"
    elif region == SyncRegion.US_WASHINGTON_2:
        return "US_WASHINGTON_2"
    raise ValueError(f"Unknown region: {region}")


SupervisedFineTuningJobWeightPrecisionLiteral = Literal["WEIGHT_PRECISION_UNSPECIFIED", "BFLOAT16", "INT8", "NF4"]


def accelerator_type_proto_to_literal(
    accelerator_type: SyncAcceleratorType,
) -> AcceleratorTypeLiteral:
    if accelerator_type == SyncAcceleratorType.ACCELERATOR_TYPE_UNSPECIFIED:
        return "ACCELERATOR_TYPE_UNSPECIFIED"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_A100_80GB:
        return "NVIDIA_A100_80GB"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_H100_80GB:
        return "NVIDIA_H100_80GB"
    elif accelerator_type == SyncAcceleratorType.AMD_MI300X_192GB:
        return "AMD_MI300X_192GB"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_A10G_24GB:
        return "NVIDIA_A10G_24GB"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_A100_40GB:
        return "NVIDIA_A100_40GB"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_L4_24GB:
        return "NVIDIA_L4_24GB"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_H200_141GB:
        return "NVIDIA_H200_141GB"
    elif accelerator_type == SyncAcceleratorType.NVIDIA_B200_180GB:
        return "NVIDIA_B200_180GB"
    raise ValueError(f"Unknown accelerator type: {accelerator_type}")


def precision_proto_to_literal(
    precision: SyncSupervisedFineTuningJob.WeightPrecision,
) -> SupervisedFineTuningJobWeightPrecisionLiteral:
    if precision == SyncSupervisedFineTuningJob.WeightPrecision.WEIGHT_PRECISION_UNSPECIFIED:
        return "WEIGHT_PRECISION_UNSPECIFIED"
    elif precision == SyncSupervisedFineTuningJob.WeightPrecision.BFLOAT16:
        return "BFLOAT16"
    elif precision == SyncSupervisedFineTuningJob.WeightPrecision.INT8:
        return "INT8"
    elif precision == SupervisedFineTuningJobWeightPrecision.NF4:
        return "NF4"
    raise ValueError(f"Unknown precision: {precision}")


JobStateLiteral = Literal[
    "UNSPECIFIED",
    "CREATING",
    "RUNNING",
    "COMPLETED",
    "FAILED",
    "CANCELLED",
    "DELETING",
    "WRITING_RESULTS",
    "VALIDATING",
    "ROLLOUT",
    "EVALUATION",
    "FAILED_CLEANING_UP",
    "DELETING_CLEANING_UP",
    "POLICY_UPDATE",
]


def job_state_proto_to_literal(state: SyncJobState) -> JobStateLiteral:
    if state == SyncJobState.JOB_STATE_UNSPECIFIED:
        return "UNSPECIFIED"
    elif state == SyncJobState.JOB_STATE_CREATING:
        return "CREATING"
    elif state == SyncJobState.JOB_STATE_RUNNING:
        return "RUNNING"
    elif state == SyncJobState.JOB_STATE_COMPLETED:
        return "COMPLETED"
    elif state == SyncJobState.JOB_STATE_FAILED:
        return "FAILED"
    elif state == SyncJobState.JOB_STATE_CANCELLED:
        return "CANCELLED"
    elif state == SyncJobState.JOB_STATE_DELETING:
        return "DELETING"
    elif state == SyncJobState.JOB_STATE_WRITING_RESULTS:
        return "WRITING_RESULTS"
    elif state == SyncJobState.JOB_STATE_VALIDATING:
        return "VALIDATING"
    elif state == SyncJobState.JOB_STATE_ROLLOUT:
        return "ROLLOUT"
    elif state == SyncJobState.JOB_STATE_EVALUATION:
        return "EVALUATION"
    elif state == SyncJobState.JOB_STATE_FAILED_CLEANING_UP:
        return "FAILED_CLEANING_UP"
    elif state == SyncJobState.JOB_STATE_DELETING_CLEANING_UP:
        return "DELETING_CLEANING_UP"
    elif state == SyncJobState.JOB_STATE_POLICY_UPDATE:
        return "POLICY_UPDATE"
    raise ValueError(f"Unknown job state: {state}")


class SupervisedFineTuningJob:
    """
    Wrapper around proto for a supervised fine-tuning job in Fireworks. Can be
    constructed from a name, LLM, and dataset. Can be used to sync the job state
    to Fireworks and query the current state.
    """

    def __init__(
        self,
        name: str,
        llm: LLM,
        dataset: Dataset,
        api_key: Optional[str] = None,
        epochs: Optional[int] = None,
        learning_rate: Optional[float] = None,
        lora_rank: Optional[int] = None,
        jinja_template: Optional[str] = None,
        early_stop: Optional[bool] = None,
        max_context_length: Optional[int] = None,
        base_model_weight_precision: Optional[SupervisedFineTuningJobWeightPrecisionLiteral] = None,
        wandb_config: Optional[WandbConfig] = None,
        evaluation_dataset: Optional[str] = None,
        accelerator_type: Optional[AcceleratorTypeLiteral] = None,
        accelerator_count: Optional[int] = None,
        is_turbo: Optional[bool] = None,
        eval_auto_carveout: Optional[bool] = None,
        region: Optional[RegionLiteral] = None,
        nodes: Optional[int] = None,
        batch_size: Optional[int] = None,
        state: Optional[JobStateLiteral] = None,
        create_time: Optional[datetime] = None,
        update_time: Optional[datetime] = None,
        created_by: Optional[str] = None,
        output_model: Optional[str] = None,
    ):
        self.name = name
        self.llm = llm
        self.dataset = dataset
        self.epochs = epochs
        self.learning_rate = learning_rate
        self.lora_rank = lora_rank
        self.jinja_template = jinja_template
        self.early_stop = early_stop
        self.max_context_length = max_context_length
        if base_model_weight_precision is not None:
            self.base_model_weight_precision = getattr(
                SupervisedFineTuningJobWeightPrecision,
                base_model_weight_precision,
            )
        self.wandb_config = wandb_config
        self.evaluation_dataset = evaluation_dataset
        if accelerator_type is not None:
            self.accelerator_type = getattr(SyncAcceleratorType, accelerator_type)
        self.accelerator_count = accelerator_count
        self.is_turbo = is_turbo
        self.eval_auto_carveout = eval_auto_carveout
        if region is not None:
            self.region = getattr(SyncRegion, region)
        self.nodes = nodes
        self.batch_size = batch_size
        if state is not None:
            self.state = JobState.from_string(state)
        self.create_time = create_time
        self.update_time = update_time
        self.created_by = created_by
        self.output_model = output_model
        self._api_key = api_key
        self._gateway = Gateway(api_key=api_key)

    @classmethod
    async def delete_by_name(cls, name: str, api_key: Optional[str] = None):
        gateway = Gateway(api_key=api_key)
        await gateway.delete_supervised_fine_tuning_job(name)
        job = await gateway.get_supervised_fine_tuning_job(name)
        while job is not None:
            await asyncio.sleep(1)

    async def delete(self):
        await self.delete_by_name(self.name, self._api_key)

    def sync(self) -> "SupervisedFineTuningJob":
        """
        Creates the job if it doesn't exist, otherwise returns the existing job.
        """
        existing_job = self.get()
        if existing_job is not None:
            return existing_job
        self.dataset.sync()
        request = self._create_request()
        self._gateway.create_supervised_fine_tuning_job_sync(request)
        new_job = self.get()
        if new_job is None:
            raise ValueError(f"Failed to create supervised fine-tuning job {self.name}")
        return new_job

    def _create_request(self) -> SyncCreateSupervisedFineTuningJobRequest:
        dataset_id = self.dataset.id()
        job_proto = SyncSupervisedFineTuningJob(
            display_name=self.name,
            base_model=self.llm.model,
            dataset=dataset_id,
        )
        if self.epochs is not None:
            job_proto.epochs = self.epochs
        if self.learning_rate is not None:
            job_proto.learning_rate = self.learning_rate
        if self.lora_rank is not None:
            job_proto.lora_rank = self.lora_rank
        if self.jinja_template is not None:
            job_proto.jinja_template = self.jinja_template
        if self.early_stop is not None:
            job_proto.early_stop = self.early_stop
        if self.max_context_length is not None:
            job_proto.max_context_length = self.max_context_length
        if self.base_model_weight_precision is not None:
            job_proto.base_model_weight_precision = self.base_model_weight_precision
        if self.wandb_config is not None:
            job_proto.wandb_config = SyncWandbConfig(
                enabled=self.wandb_config.enabled,
                api_key=self.wandb_config.api_key,
                project=self.wandb_config.project,
                entity=self.wandb_config.entity,
                run_id=self.wandb_config.run_id,
            )
        if self.evaluation_dataset is not None:
            job_proto.evaluation_dataset = self.evaluation_dataset
        if self.accelerator_type is not None:
            job_proto.accelerator_type = self.accelerator_type
        if self.accelerator_count is not None:
            job_proto.accelerator_count = self.accelerator_count
        if self.is_turbo is not None:
            job_proto.is_turbo = self.is_turbo
        if self.eval_auto_carveout is not None:
            job_proto.eval_auto_carveout = self.eval_auto_carveout
        if self.region is not None:
            job_proto.region = self.region
        if self.nodes is not None:
            job_proto.nodes = self.nodes
        if self.batch_size is not None:
            job_proto.batch_size = self.batch_size
        if self.output_model is not None:
            job_proto.output_model = self.output_model
        request = SyncCreateSupervisedFineTuningJobRequest(
            supervised_fine_tuning_job=job_proto,
        )
        return request

    def get(self) -> Optional["SupervisedFineTuningJob"]:
        """
        TODO: we should not be using display_name to find the job, but instead
        the name. But due to a bug when reusing the same Job ID, we need to use
        display_name as our identifier.
        """
        request = SyncListSupervisedFineTuningJobsRequest()
        page_token = None
        while True:
            if page_token is not None:
                request.page_token = page_token
            list_response = self._gateway.list_supervised_fine_tuning_jobs_sync(request)
            for job_proto in list_response.supervised_fine_tuning_jobs:
                if job_proto.display_name == self.name:
                    return SupervisedFineTuningJob(
                        name=job_proto.display_name,
                        llm=self.llm,
                        dataset=self.dataset,
                        api_key=self._api_key,
                        state=job_state_proto_to_literal(job_proto.state),
                        epochs=job_proto.epochs,
                        learning_rate=job_proto.learning_rate,
                        lora_rank=job_proto.lora_rank,
                        jinja_template=job_proto.jinja_template,
                        early_stop=job_proto.early_stop,
                        max_context_length=job_proto.max_context_length,
                        base_model_weight_precision=precision_proto_to_literal(job_proto.base_model_weight_precision),
                        wandb_config=wandb_config_proto_to_dataclass(job_proto.wandb_config),
                        evaluation_dataset=job_proto.evaluation_dataset,
                        accelerator_type=accelerator_type_proto_to_literal(job_proto.accelerator_type),
                        accelerator_count=job_proto.accelerator_count,
                        is_turbo=job_proto.is_turbo,
                        eval_auto_carveout=job_proto.eval_auto_carveout,
                        region=region_proto_to_literal(job_proto.region),
                        nodes=job_proto.nodes,
                        batch_size=job_proto.batch_size,
                        create_time=timestamp_proto_to_datetime(job_proto.create_time),
                        update_time=timestamp_proto_to_datetime(job_proto.update_time),
                        created_by=job_proto.created_by,
                        output_model=job_proto.output_model,
                    )
            if not list_response.next_page_token:
                return None
            page_token = list_response.next_page_token



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/feature_flag.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/feature_flag.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agateway/feature_flag.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xed\x01\n\x0b\x46\x65\x61tureFlag\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05:|\xea\x41l\n\x1c\x61pi.fireworks.ai/FeatureFlag\x12\x31\x61\x63\x63ounts/{AccountId}/featureFlags/{FeatureFlagId}*\x0c\x66\x65\x61tureFlags2\x0b\x66\x65\x61tureFlag\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"\x81\x01\n\x18\x43reateFeatureFlagRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x30\n\x0c\x66\x65\x61ture_flag\x18\x02 \x01(\x0b\x32\x14.gateway.FeatureFlagB\x04\xe2\x41\x01\x02\x12\x1d\n\x0f\x66\x65\x61ture_flag_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"+\n\x15GetFeatureFlagRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x90\x01\n\x17ListFeatureFlagsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"t\n\x18ListFeatureFlagsResponse\x12+\n\rfeature_flags\x18\x01 \x03(\x0b\x32\x14.gateway.FeatureFlag\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x83\x01\n\x18UpdateFeatureFlagRequest\x12\x30\n\x0c\x66\x65\x61ture_flag\x18\x01 \x01(\x0b\x32\x14.gateway.FeatureFlagB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\".\n\x18\x44\x65leteFeatureFlagRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.feature_flag_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_FEATUREFLAG'].fields_by_name['name']._loaded_options = None
  _globals['_FEATUREFLAG'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_FEATUREFLAG'].fields_by_name['value']._loaded_options = None
  _globals['_FEATUREFLAG'].fields_by_name['value']._serialized_options = b'\342A\001\001'
  _globals['_FEATUREFLAG'].fields_by_name['create_time']._loaded_options = None
  _globals['_FEATUREFLAG'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_FEATUREFLAG']._loaded_options = None
  _globals['_FEATUREFLAG']._serialized_options = b'\352Al\n\034api.fireworks.ai/FeatureFlag\0221accounts/{AccountId}/featureFlags/{FeatureFlagId}*\014featureFlags2\013featureFlag\202\361\004\t\n\007Account'
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._loaded_options = None
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag_id']._loaded_options = None
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag_id']._serialized_options = b'\342A\001\002'
  _globals['_GETFEATUREFLAGREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETFEATUREFLAGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._loaded_options = None
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEFEATUREFLAGREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEFEATUREFLAGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_FEATUREFLAG']._serialized_start=190
  _globals['_FEATUREFLAG']._serialized_end=427
  _globals['_CREATEFEATUREFLAGREQUEST']._serialized_start=430
  _globals['_CREATEFEATUREFLAGREQUEST']._serialized_end=559
  _globals['_GETFEATUREFLAGREQUEST']._serialized_start=561
  _globals['_GETFEATUREFLAGREQUEST']._serialized_end=604
  _globals['_LISTFEATUREFLAGSREQUEST']._serialized_start=607
  _globals['_LISTFEATUREFLAGSREQUEST']._serialized_end=751
  _globals['_LISTFEATUREFLAGSRESPONSE']._serialized_start=753
  _globals['_LISTFEATUREFLAGSRESPONSE']._serialized_end=869
  _globals['_UPDATEFEATUREFLAGREQUEST']._serialized_start=872
  _globals['_UPDATEFEATUREFLAGREQUEST']._serialized_end=1003
  _globals['_DELETEFEATUREFLAGREQUEST']._serialized_start=1005
  _globals['_DELETEFEATUREFLAGREQUEST']._serialized_end=1051
# @@protoc_insertion_point(module_scope)
